pyoda\_time.text package
========================

Subpackages
-----------

.. toctree::
   :maxdepth: 1

   pyoda_time.text.patterns

Module contents
---------------

.. automodule:: pyoda_time.text
   :members:
   :undoc-members:
   :show-inheritance:
